# USER SETTINGS SCRIPT FOR SENDING PUSHOVER NOTIFICATIONS WITH A GIF FILE ATTACHMENT
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'pushover_resize.ps1'
#   2. This script must be located in the same folder as script 'pushover_resize.ps1'
#   3. This script is suitable for 'BI_gif_tool.ps1' versions V2.1+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# ENTER THIS APP'S FOLDER LOCATION
	# ... [string] like, "D:\BI_gif_tool"
	# ... This will be the root folder for CSV, GIF, and JPG files created by this script
	$app_path = "YOUR_APP_FOLDER_PATH"

	# ENTER BLUE IRIS 'ALERTS' FOLDER PATH (LOCATION OF AI 'DAT' FILES)
	# ... [string] like 'D:\BlueIris\Alerts'
	# ... KEY POINT: If using a network share for Blue Iris storage, note that the BI service may
	#     not understand your file system designations like 'H:' etc. as these are user-specific. 
	#     Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_alerts_folder_path = "YOUR_BLUE_IRIS_ALERTS_FOLDER_PATH"

	# ENTER BLUE IRIS 'NEW' FOLDER PATH(S) (LOCATION OF BVR FILES)
	# ... (list) comma-delimited, like 'D:\BlueIris\New','J:\BlueIris\New'
	# ... At least one value is required
	# ... Use multiple values if your Blue Iris system is configured to use multiple 'New' folders
	# ... KEY POINT: If using a network share for Blue Iris storage, note that the BI service may
	#     not understand your file system designations like 'H:' etc. as these are user-specific. 
	#     Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_new_folder_paths = 'YOUR_BLUE_IRIS_NEW_FOLDER_PATH(S)'

	# ENTER BLUE WEBSERVER ADDRESS & PORT
	# ... [string] like "192.168.1.3:81"
	# ... To use credentials, be sure to uncheck 'Use secure session keys and login page' 
	#     in Blue Iris settings: click Settings > Web server > Advanced
	$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

	# ENTER BLUE IRIS WEBSERVER USERNAME & PASSWORD 
	# ... [string] 
	# ... NOTE: ACCOUNT MUST BE ADMIN TO POST TO CUSTOM MESSAGES TO THE BLUE IRIS LOGFILE
	$bi_user_name = "YOUR_BI_USER_NAME"
	$bi_user_pw = "YOUR_BI_USER_PASSORD"

	# ENTER DEFAULT PUSH APPLICATION
	# ... expecting "Pushover" or "Telegram", case-insensitive (default is 'Pushover")
	# ... maybe overridden using argument -PushMethod
	$push_service = "Pushover"
	#$push_service = "Telegram"

	# IF USING PUSHOVER ...

		# ENTER YOUR PUSHOVER API USER KEY
		# ... https://pushover.net/
		$po_user_token = "YOUR_API_USER_KEY"

		# ENTER YOUR PUSHOVER API APPLICATION TOKEN
		# ... https://pushover.net/ (scroll down to 'Your Applications')
		# ... TIP: consider adding a 'PowerShell' application to your https://pushover.net/ account
		$po_app_token = "YOUR_API_APPLICATION_TOKEN"

	# IF USING TELEGRAM ...
	
		# Setting up: 
		# Use the following link to create a new Telegram Bot token and a Blue Iris 'channel' chat id.
		# (I named my channel 'Blueiris_xxx' ... xxx = my initials) 
		# http://www.marrold.co.uk/2017/04/push-notifications-from-tasker-to.html
		
		# Notification customization: 
		# Unlike Pushover, Telegram does not support server-side customization of notifications (only device-side). 
		# So customizations must be set up on your device:
		# 1. Open the Telegram app on your device after receiving a notification
		# 2. Tap the channel name > Notifications > Customize
		# 3. Customize the sound, vibration, repeat frequency, and priority
		# 4. Restart your device (required for my Samsung Galaxy S24+)

		# ENTER YOUR TELEGRAM BOT API TOKEN
		# ... https://core.telegram.org/bots
		$tg_api_token = "YOUR_API_TOKEN"
]
		# ENTER YOUR TELEGRAM BOT CHAT ID
		# ... https://core.telegram.org/bots
		$tg_chat_id = "YOUR_CHAT_ID"	

# OPTIONAL SETTINGS

	# SCRIPT OPTIONS

		# OPT-OUT OF CHECKS AND MESSAGING INTENDED TO HELP NEW USERS
		# ... Expecting $true or $false (default is $false)
		$experienced_user_flg = $false
		#$experienced_user_flg = $true

		# OPT-OUT OF BACKGROUND MESSAGING
		# ... [boolean]
		# ... Default is $true
		# ... Key Points: 
		#     1. Background messages are enabled only if script is running in the background
		#     2. This global setting may be overridden by argument '-Quiet'
		$bg_msgs_on = $true
		#$bg_msgs_on = $false

	# GIF FILE GLOBAL OPTIONS

		# ENTER GIF'S HEIGHT DIMENSION
		# ... [integer] units are pix
		# ... Default is 320
		# ... The aspect ratio is unchanged by resizing
		$gif_height = 320

		# ENTER GIF FRAMES PER SECOND
		# ... [integer] 
		# ... Default is 2
		# ... Use a higher value to make the GIF play faster
		$gif_fps = 2

		# ENTER MAX LIFETIME FOR ARCHIVED GIF FILES
		# ... All GIF files created by this script are automatically archived to folder '$app_path\_gif_archive'
		# ... To prevent this folder from growing excessively large, this setting deletes GIF files after a given age
		#     (aka a 'pruning operation' that searches for backups older than a retention time)
		# ... TIP: Use 0 to disable monitoring of the this archive folder
		# ... Default is 720 hours (30 days)
		$gif_archive_lifetime_hours = 720

	# SOURCING GIF FILES FROM BLUE IRIS 'DAT' FILES

		# ENTER REQUIRED NUMBER OF JPGs IN 'DAT' FILE
		# ... [integer] 
		# ... Default is 4
		# ... Otherwise, the GIF will be created from the BLUE IRIS VIDEO CLIP (BVR)
		# ... TIP: set to high value to force GIF creation from BVR clip
		$gif_DAT_reqd_images_cnt = 4
		#$gif_DAT_reqd_images_cnt = 30

		# ENTER THE DEFAULT TIME INTERVAL BETWEEN DAT IMAGES
		# ... [integer] 
		# ... Default is 500
		# ... To customize camera-specific intervals, use argument -DatImageMsec X
		#     where X is via BI > Camera settings > Alert > AI Configuration > 'Analyze one image each'
		$dat_image_interval_msec = 500

	# SOURCING GIF FILES FROM BLUE IRIS VIDEO CLIPS (BVRs)

		# TIP: set '$gif_DAT_reqd_images_cnt' to high value (next section) to force GIF creation from BVR clip

		# ENTER COUNT OF JPGS TO USE IN THE GIF ANIMATION
		# ... [integer] 
		# ... Default is 10
		$gif_images_cnt = 10

		# ENTER PERCENTAGE OF ALERT CLIP TO ALWAYS TRIM FROM (OR ADD TO) THE LEFT SIDE FOR GIF ANIMATION
		# ... Use to remove or increase the portion of the Alert's duration shown in the GIF
		# ... Expecting a +/- integer (default is 0)
		# ... Positive values may be used with both DAT and BVR derived GIFs
		# ... Negative values may be used ONLY by BVR derived GIFs (JPGs will be collected BEFORE Alert's database offset)
		# ... Use cmdline argument -TrimBegPct to customize the trim percent for specific cameras
		# ... NOTE: The sum of $gif_trim_beg + $gif_trim_end (or gif_trim_end_cust) must be between 0 and 100
		$gif_trim_beg = 0

		# ENTER PERCENTAGE OF ALERT CLIP TO ALWAYS TRIM FROM RIGHT SIDE FOR GIF ANIMATION
		# ... Use to eliminate the right-side portion of the Alert's duration shown in the GIF
		# ... Expecting integer > 0 (default is 0)
		# ... Use cmdline argument -TrimEndPct to customize the trim percent for specific cameras
		# ... NOTE: The sum of $gif_trim_beg + $gif_trim_end (or gif_trim_end_cust) must be between 0 and 100
		$gif_trim_end = 0
		#$gif_trim_end = 40

		# CUSTOMIZE ALERT CLIP RIGHT TRIM BASED ON AI RESULTS
		# ... WHY? Faster moving objects may result in a GIF with just a couple of frames
		# ... expecting an object, like, @{ 'ai_label_1' = pct ; 'ai_label_1' = pct ; ... } 
		# ... Default is @{}
		# ... Use positive values for fast-moving objects (to use less of the clip)
		# ... Use negative values for slow/random-moving objects (to use more of the clip)
		# ... NOTE: The sum of $gif_trim_beg + gif_trim_end_cust must be between 0 and 100
		# ... NOTE: Activated by use of argument -AlertMemo '&MEMO' in Blue Iris Action Set run-a-program action
		$gif_trim_end_cust_obj = @{}
		<# $gif_trim_end_cust_obj = @{
			'vehicle' = 30  # Use fewer clips for fast moving objects
			'car' = 30
			'truck' = 20
			#'person' = 5
			#'dog' = -40  # Use the whole clip for slow/random moving objects
			#'cat' = -40 
		} #>

	# NOTIFICATION MESSAGE DEFAULTS (ALL PUSH SERVICES)

		# OPT-OUT OF APPENDING GIF METHOD TAGS LIKE TO NOTIFICATIONS MESSAGES
		# ... These tags are like ' (viaDAT:n)' or ' (viaClip)' or ' (viaLiveStream)', where n is the number of JPGs found in the DAT file
		#     The number is MAXIMUM number of JPGs that may be used in to make the GIF file
		# ... [boolean] 
		# ... Default is $true
		$append_gif_method_tag_flg = $true
		#$append_gif_method_tag_flg = $false

		# OPT-OUT OF APPENDING SCRIPT PERFORMANCE (GIF MAKE TIME) TO NOTIFICATIONS MESSAGES
		# ... These tags are like 'GifMakeTime: 1234 msec'
		# ... [boolean] 
		# ... Default is $true
		$append_performance_tag_flg = $true
		#$append_performance_tag_flg = $false

	# PUSHOVER NOTIFICATION DEFAULTS

		# ENTER PUSHOVER MESSAGE PRIORITY
		# ... (integer) -2|-1|0|1|2; -2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency
		# ... Default is 0
		# ... see https://pushover.net/api#priority
		$po_priority = 0

		# ENTER PUSHOVER SOUND
		# ... Default is "" (Pushover default sound)
		# ... see https://pushover.net/api#sounds
		$po_sound = ""  # default sound
		#$po_sound = "siren"  # built-in sound
		#$po_sound = "not-kiddin"  # custom sound

		# ENTER PUSHOVER DEVICE(S)
		# ... Default is "" (All Pushover devices)
		# ... may be comma-delimited list.
		# ... see https://pushover.net/api
		$po_device = ""  # all devices
		#$po_device = "galaxy-s24"  # single device
		#$po_device = "galaxy-s24,iPhoneXS"  # multiple devices

		# ENTER PUSHOVER RETRY PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... Default is 30
		# ... see https://pushover.net/api#priority
		$po_retry = 30

		# ENTER PUSHOVER EXPIRE PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... Default is 300
		# ... see https://pushover.net/api#priority
		$po_expire = 300

		# ENTER PUSHOVER EMERGENCE PRIORITY TAGS
		# ... blank ("") is default tag
		# ... see https://pushover.net/api#priority
		$po_tags = ""
		#$po_tags = "a=BI,c=&CAM,g=Front"  # custom tags
		#$po_tags = "a=BI,c=&CAM"  # custom tags

	# LOGGING TO THE BLUE IRIS LOGFILE

		# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
		# ... expecting $false or $true (default = $false)
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

		# OPT-IN TO USE CREDENTIALS FOR POSTING TO THE BLUE IRIS LOGFILE
		# ... expecting $false or $true (default = $false)
		$post_w_creds_flg = $false
		#$post_w_creds_flg = $true

		# OPT-IN TO LOGGING ALL EVENTS (NOT JUST ERRORS)
		# ... [boolean]
		# ... expecting $false or $true (default = $true)
		$post_all_events = $true
		#$post_all_events = $false

# END USER SETTINGS
# ===============================================
